@@ -31,6 +31,7 @@ from telegram import (
     TelegramObject,
     ChatMemberUpdated,
     constants,
+    ChatJoinRequest,
 )
 from telegram.poll import PollAnswer
 from telegram.utils.types import JSONDict
@@ -89,6 +90,12 @@ class Update(TelegramObject):
             :meth:`telegram.ext.Updater.start_webhook`).
 
             .. versionadded:: 13.4
+        chat_join_request (:class:`telegram.ChatJoinRequest`, optional): A request to join the
+            chat has been sent. The bot must have the
+            :attr:`telegram.ChatPermissions.can_invite_users` administrator right in the chat to
+            receive these updates.
+
+            .. versionadded:: 13.8
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
 
     Attributes:
@@ -122,6 +129,11 @@ class Update(TelegramObject):
             :meth:`telegram.ext.Updater.start_webhook`).
 
             .. versionadded:: 13.4
+        chat_join_request (:class:`telegram.ChatJoinRequest`): Optional. A request to join the
+            chat has been sent. The bot must have the ``'can_invite_users'`` administrator
+            right in the chat to receive these updates.
+
+            .. versionadded:: 13.8
 
     """
 
@@ -143,6 +155,7 @@ class Update(TelegramObject):
         '_effective_message',
         'my_chat_member',
         'chat_member',
+        'chat_join_request',
         '_id_attrs',
     )
 
@@ -198,6 +211,10 @@ class Update(TelegramObject):
     """:const:`telegram.constants.UPDATE_CHAT_MEMBER`
 
     .. versionadded:: 13.5"""
+    CHAT_JOIN_REQUEST = constants.UPDATE_CHAT_JOIN_REQUEST
+    """:const:`telegram.constants.UPDATE_CHAT_JOIN_REQUEST`
+
+    .. versionadded:: 13.8"""
     ALL_TYPES = constants.UPDATE_ALL_TYPES
     """:const:`telegram.constants.UPDATE_ALL_TYPES`
 
@@ -219,6 +236,7 @@ class Update(TelegramObject):
         poll_answer: PollAnswer = None,
         my_chat_member: ChatMemberUpdated = None,
         chat_member: ChatMemberUpdated = None,
+        chat_join_request: ChatJoinRequest = None,
         **_kwargs: Any,
     ):
         # Required
@@ -237,6 +255,7 @@ class Update(TelegramObject):
         self.poll_answer = poll_answer
         self.my_chat_member = my_chat_member
         self.chat_member = chat_member
+        self.chat_join_request = chat_join_request
 
         self._effective_user: Optional['User'] = None
         self._effective_chat: Optional['Chat'] = None
@@ -286,6 +305,9 @@ class Update(TelegramObject):
         elif self.chat_member:
             user = self.chat_member.from_user
 
+        elif self.chat_join_request:
+            user = self.chat_join_request.from_user
+
         self._effective_user = user
         return user
 
@@ -325,6 +347,9 @@ class Update(TelegramObject):
         elif self.chat_member:
             chat = self.chat_member.chat
 
+        elif self.chat_join_request:
+            chat = self.chat_join_request.chat
+
         self._effective_chat = chat
         return chat
 
@@ -334,8 +359,10 @@ class Update(TelegramObject):
         :class:`telegram.Message`: The message included in this update, no matter what kind of
             update this is. Will be :obj:`None` for :attr:`inline_query`,
             :attr:`chosen_inline_result`, :attr:`callback_query` from inline messages,
-            :attr:`shipping_query`, :attr:`pre_checkout_query`, :attr:`poll` and
-            :attr:`poll_answer`.
+            :attr:`shipping_query`, :attr:`pre_checkout_query`, :attr:`poll`,
+            :attr:`poll_answer`, :attr:`my_chat_member`, :attr:`chat_member` as well as
+            :attr:`chat_join_request` in case the bot is missing the
+            :attr:`telegram.ChatPermissions.can_invite_users` administrator right in the chat.
 
         """
         if self._effective_message:
@@ -384,5 +411,6 @@ class Update(TelegramObject):
         data['poll_answer'] = PollAnswer.de_json(data.get('poll_answer'), bot)
         data['my_chat_member'] = ChatMemberUpdated.de_json(data.get('my_chat_member'), bot)
         data['chat_member'] = ChatMemberUpdated.de_json(data.get('chat_member'), bot)
+        data['chat_join_request'] = ChatJoinRequest.de_json(data.get('chat_join_request'), bot)
 
         return cls(**data)
